@@ -60,7 +60,7 @@ options = [
     Option("CompressExtension", "gz", "string", Option.USER, False,
            "If archived logs will be compressed, the file extension to use on compressed log files. When specifying a file extension, don't include the period character (e.g., specify 'gz' instead of '.gz')."),
 
-    Option("SendMail", "/usr/sbin/sendmail", "string", Option.USER, False,
+    Option("SendMail", "/usr/local/sbin/sendmail", "string", Option.USER, False,
            "Location of the sendmail binary.  Make this string blank to prevent email from being sent. The default value is configuration-dependent and determined automatically by CMake at configure-time. This overrides the Bro script variable Notice::sendmail."),
     Option("MailSubjectPrefix", "[Bro]", "string", Option.USER, False,
            "General Subject prefix for mails. This overrides the Bro script variable Notice::mail_subject_prefix."),
@@ -83,19 +83,23 @@ options = [
            "True to enable sending mail when broctl cron notices the availability of a host in the cluster to have changed."),
     Option("MailArchiveLogFail", 1, "bool", Option.USER, False,
            "True to enable sending mail when log files fail to be archived."),
+    Option("MailReceivingPackets", 1, "bool", Option.USER, False,
+           "True to enable sending mail when broctl cron notices that an interface is not receiving any packets (note that such mail is not sent when StatsLogEnable is 0)."),
 
     Option("MinDiskSpace", 5, "int", Option.USER, False,
-           "Percentage of minimum disk space available before warning is mailed."),
+           "Minimum percentage of disk space available before broctl cron mails a warning.  If this value is 0, then no warning will be sent."),
     Option("StatsLogEnable", 1, "bool", Option.USER, False,
            "True to enable BroControl to write statistics to the stats.log file."),
     Option("StatsLogExpireInterval", 0, "int", Option.USER, False,
            "Number of days entries in the stats.log file are kept (zero means never expire)."),
+    Option("CrashExpireInterval", 0, "int", Option.USER, False,
+           "Number of days that crash directories are kept (zero means never expire)."),
     Option("LogExpireInterval", "0", "string", Option.USER, False,
            "Time interval that archived log files are kept (a value of 0 means log files never expire).  The time interval is expressed as an integer followed by one of the following time units: day, hr, min."),
     Option("KeepLogs", "", "string", Option.USER, False,
            "A space-separated list of filename shell patterns of expired log files to keep (empty string means don't keep any expired log files). The filename shell patterns are not regular expressions and do not include any directories. For example, specifying 'conn.* dns*' will prevent any expired log files with filenames starting with 'conn.' or 'dns' from being removed. Finally, note that this option is ignored if log files never expire."),
     Option("BroArgs", "", "string", Option.USER, False,
-           "Additional arguments to pass to Bro on the command-line (e.g. broargs=-f \"tcp port 80\")."),
+           'Additional arguments to pass to Bro on the command-line (e.g. broargs=-f "tcp port 80").'),
     Option("MemLimit", "unlimited", "string", Option.USER, False,
            "Maximum amount of memory for Bro processes to use (in KB, or the string 'unlimited')."),
     Option("Env_Vars", "", "string", Option.USER, False,
@@ -120,6 +124,8 @@ options = [
 
     Option("StatusCmdShowAll", 0, "bool", Option.USER, False,
            "True to have the status command show all output, or False to show only some of the output (peer information will not be collected or shown, so the command will run faster)."),
+    Option("StopWait", 0, "bool", Option.USER, False,
+           "True to force the stop command to wait for the post-terminate script to finish, or False to let post-terminate finish in the background."),
 
     Option("CronCmd", "", "string", Option.USER, False,
            "A custom command to run everytime the cron command has finished."),
